OpenPeepsAssets class

Constructors

OpenPeepsAssets()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

facialHair Map<String, String Function({required String clothingColor, required String hairColor, required String skinColor})>
final
final

Constants

accessories → const Map<String, String>
face → const Map<String, String>
mask → const Map<String, String>