DicebearProfileManager class

Constructors

DicebearProfileManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

deleteAvatarPayload(int index) Future<void>
Deletes a saved avatar payload by its index.
deleteAvatarSvg(int index) Future<void>
getSavedAvatarPayloads() Future<List<Uint8List>>
Retrieves all saved 13-byte avatar payloads from local storage.
getSavedAvatarSvgs() Future<List<String>>
saveAvatarPayload(Uint8List payload) Future<void>
Saves a 13-byte avatar payload to local storage.
saveAvatarSvg(String svgString) Future<void>