SvgEngine class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
generateSvg({required AvatarStyle style, required String headOrHairKey, required String faceOrEyesKey, required String hairColor, required String skinColor, required String clothingColor, String? facialHairKey, String? accessoriesKey, String? maskKey, String? bodyKey, String? mouthKey, String? noseKey, String? eyebrowsKey, String? earsKey, String? glassesKey, String? earringsKey, String? earringColor, String? eyeShadowColor, String? eyesColor, String? glassesColor, String? mouthColor, String? eyebrowsColor, String? rearHairKey, String? avataaarStyleKey, String? clothingGraphicKey, String? accessoriesColor, String? hatColor, String? facialHairColor, String? backgroundColor})
→ String
-